@@ -4,14 +4,14 @@ import {Map, Seq, Iterable} from 'immutable';
 import {MODE_IDLE, MODE_3D_VIEW, MODE_3D_FIRST_PERSON} from '../../../constants';
 import PropertiesEditor from './properties-editor';
 
-export default function PanelPropertiesEditor({state}) {
+export default function PanelPropertiesEditor({state}, {translator}) {
 
   let {scene, mode} = state;
 
   if (![MODE_IDLE, MODE_3D_VIEW, MODE_3D_FIRST_PERSON].includes(mode)) return null;
 
   let componentRenderer = (element, layer) =>
-    <Panel key={element.id} name={`Properties: [${element.type}] ${element.id}`}>
+    <Panel key={element.id} name={translator.t("Properties: [{0}] {1}", element.type, element.id)}>
       <div style={{padding: "5px 15px 5px 15px"}}>
         <PropertiesEditor element={element} layer={layer} state={state}/>
       </div>
@@ -33,3 +33,7 @@ export default function PanelPropertiesEditor({state}) {
 PanelPropertiesEditor.propTypes = {
   state: PropTypes.object.isRequired,
 };
+
+PanelPropertiesEditor.contextTypes= {
+  translator: PropTypes.object.isRequired
+};
